#!/bin/sh
##*************************************************************************##
##  CUBE        http://www.scalasca.org/                                   ##
##*************************************************************************##
##  Copyright (c) 2020-2024                                                ##
##  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          ##
##                                                                         ##
##  This software may be modified and distributed under the terms of       ##
##  a BSD-style license.  See the COPYING file in the package base         ##
##  directory for details.                                                 ##
##*************************************************************************##


BUILD_DIR=`pwd`/../../../..

QT=$HOME/Qt/6.4.2
ANDROID_CUBE_SRC=$BUILD_DIR/CubeLib/cubelib/vendor/windows/cube/android-build


arch=$1
version=$2
version_as_number=$3
cmd=cmd_build

if test "x$arch" == "xclean"; then
cmd="cmd_clean"
fi

mkdir -p GUI-qt
curdir=`pwd`

cmd_build_lib()
{


echo "Read version and SHA in VERSION and REVISION files"

cat ../../build-config/VERSION | grep "package.major"  | sed -e "s/package\.major=//g"> package.major
cat ../../build-config/VERSION | grep "package.minor"  | sed -e "s/package\.minor=//g"> package.minor
cat ../../build-config/VERSION | grep "package.bugfix" | sed -e "s/package\.bugfix=//g"> package.bugfix
cat ../../build-config/VERSION | grep "package.suffix" | sed -e "s/package\.suffix=//g"> package.suffix

REVISION=$(cat ../../build-config/REVISION)

echo "Read Cube version"
PACKAGEMAJOR=$(cat package.major)
PACKAGEMINOR=$(cat package.minor)
PACKAGEBUGIX=$(cat package.bugfix)
PACKAGESUFFIX=$(cat package.suffix)

rm package.major
rm package.minor
rm package.bugfix
rm package.suffix

echo "Fix cibelib-version.h Backup"
cp ./include/cubegui-version.h ./cubegui-version.source
ls
echo "Fix version and SHA in version.h"
cat cubegui-version.source | sed -e "s/<REVISION SHA>/$REVISION/g" | sed -e "s/<PACKAGE MAJOR>/$PACKAGEMAJOR/g" |   sed -e "s/<PACKAGE MINOR>/$PACKAGEMINOR/g" |   sed -e "s/<PACKAGE BUGFIX>/$PACKAGEBUGIX/g" |   sed -e "s/<PACKAGE SUFFIX>/$PACKAGESUFFIX/g"  > ./include/cubegui-version.h
rm cubegui-version.source

echo "Build $version, $version_as_number for $arch"


cat ./GUI-qt/android/build.gradle.in | sed -e "s/__BUILD_VERSION_CODE__/$version/g" | sed -e "s/__BUILD_VERSION_NUMBER__/$version_as_number/g" | sed -e "s/__BUILD_ARCHITECTURE__/$arch/g"  > ./GUI-qt/android/build.gradle


mkdir -p GUI-qt/plugins
curdir=`pwd`
for i in GUI-qt-core ;
        do
cd $i;
make clean
rm -f *.so
CUBE_LOCATION_V=${CUBE_LOCATION}
$ANDROID_QMAKE CUBE_LOCATION_V=${CUBE_LOCATION}
echo ""
echo "=== Build library $i for $arch"
echo ""
make -j 14 apk_install_target CUBE_LOCATION_V=${CUBE_LOCATION}
echo ""
echo "--- Copy library $i into ../GUI-qt"
echo ""
cp -rf android-build ../GUI-qt/.
echo ""
echo " --- DONE"
echo ""
cd $curdir
done

#mkdir -p GUI-qt/android-build/plugins
curdir=`pwd`
for i in GUI-plugin-advanced-colormap \
         GUI-plugin-advisor \
         GUI-plugin-diff \
         GUI-plugin-launch \
         GUI-plugin-measurement \
         GUI-plugin-mean \
         GUI-plugin-merge \
         GUI-plugin-metriceditor \
         GUI-plugin-metricident \
         GUI-plugin-scaling \
         GUI-plugin-scorepconfig \
         GUI-plugin-sourcecodeviewer \
         GUI-plugin-statistics  \
         GUI-plugin-sunburst  \
         GUI-plugin-systemboxplot  \
         GUI-plugin-systemtopology \
         GUI-plugin-tau2cube \
         GUI-plugin-treeitemmarker ;
         do
echo "Copy plugin  $i for $arch";
cd $i;
make clean
rm -f *.so
CUBE_LOCATION_V=${CUBE_LOCATION}
$ANDROID_QMAKE CUBE_LOCATION_V=${CUBE_LOCATION}
echo ""
echo "=== Build plugin $i"
echo ""
make -j 14 apk_install_target CUBE_LOCATION_V=${CUBE_LOCATION}
echo ""
echo "--- Copy plugin $i into ../GUI-qt/android-build/libs"
echo ""
cp -rf android-build ../GUI-qt/.
cp -R android-build/libs/   * ../GUI-qt/plugins/.
cd $curdir
done


}

cmd_build_apk()
{






for i in GUI-qt
        do
echo ""
echo "=== Build app  $i for $arch";
echo ""
cd $i
$ANDROID_QMAKE
make -j 14 apk_install_target  CUBE_LOCATION_V=${CUBE_LOCATION}
echo ""
echo "--- Copy Cube Lib to APK libs directory"
echo ""
cp -rf $ANDROID_CUBE_SRC .
cd $curdir
done

}


cmd_build_bundles()
{
for i in GUI-qt
        do
echo ""
echo "=== Build app  $i ";
echo ""
cd $i
echo "--- Create APK"
echo ""
make apk
echo "--- Create AAB"
echo ""
make aab
cd $curdir
done

}


cmd_build()
{

#android_archs='arm64_v8a armv7 x86 x86_64'
ANDROID_QMAKE=$QT/android_$arch/bin/qmake

make clean

cmd_build_lib

cmd_build_apk

cmd_build_bundles


}

cmd_clean()
{
curdir=`pwd`
for i in GUI-qt-core \
         GUI-qt  \
         GUI-plugin-advanced-colormap \
         GUI-plugin-advisor \
         GUI-plugin-diff \
         GUI-plugin-launch \
         GUI-plugin-mean \
         GUI-plugin-merge \
         GUI-plugin-metriceditor \
         GUI-plugin-metricident \
         GUI-plugin-scaling \
         GUI-plugin-scorepconfig \
         GUI-plugin-sourcecodeviewer \
         GUI-plugin-statistics  \
         GUI-plugin-sunburst  \
         GUI-plugin-systemboxplot  \
         GUI-plugin-systemtopology \
         GUI-plugin-tau2cube \
         GUI-plugin-treeitemmarker  ;
        do
echo "=== Clean $i"
cd $i
make clean
rm -rf android-build
rm -f Makefile*
rm -f *.so
rm -f *.json
rm -rf arm64-v8a
rm -rf armeabi-v7a
rm -rf x86
rm -rf x86_64
cd $curdir
done
}

${cmd}



# /.../AndroidSDK/build-tools/33.0.0/apksigner sign --ks ~/Soft/Cube2.0/keyStore/cube.scalasca.keystore --ks-key-alias cube.scalasca --min-sdk-version 33 android-build-release.aab
